DrawerDelegate class abstract

Drawer代理

Implementers

Constructors

DrawerDelegate({Widget? header, Widget? footer})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFooter() → Widget?
底部控件
buildHeader() → DrawerHeader?
定制头部
buildList(BuildContext context) → List<Widget>
构建菜单列表
enableHeader() → bool
是否显示头部定制区域
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited